@@ -1,6 +1,6 @@
 package SPVM::File::Temp;
 
-our $VERSION = "0.021";
+our $VERSION = "0.022";
 
 1;
 
@@ -10,21 +10,23 @@ SPVM::File::Temp - Creating Temporary Files and Directories
 
 =head1 Description
 
-The File::Temp class of L<SPVM> has methods to create temporary files and directories.
+The File::Temp class in L<SPVM> has methods to create temporary files and directories.
 
 =head1 Usage
 
   use File::Temp;
   
   my $tmp_dir = File::Temp->newdir;
+  
+  my $tmp_dir_name = $tmp_dir->dirname;
 
 =head1 Class Methods
 
 =head2 newdir
 
-  static method newdir : File::Temp::Dir ()  {
+C<static method newdir : L<File::Temp::Dir|SPVM::File::Temp::Dir> ();>
 
-Creates a temporary directory and returns a L<File::Temp::Dir|SPVM::File::Temp::Dir> object.
+Creates a temporary directory and returns a new L<File::Temp::Dir|SPVM::File::Temp::Dir> object.
 
 =head1 Repository
 
